@@ -340,9 +340,7 @@ where
                 for (_, stmt) in entry.iter_mut() {
                     let var = match stmt {
                         ModuleItem::Stmt(Stmt::Decl(Decl::Var(
-                            var
-                            @
-                            VarDecl {
+                            var @ VarDecl {
                                 kind: VarDeclKind::Const,
                                 ..
                             },
